@@ -13,11 +13,11 @@
 #include "MessageCore/StringUtil"
 
 #include "messagecomposer_debug.h"
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
+#include <KMime/DateFormatter>
+#include <KMime/MDN>
 #include <KMime/Message>
-#include <kidentitymanagement/identity.h>
-#include <kidentitymanagement/identitymanager.h>
-#include <kmime/kmime_dateformatter.h>
-#include <kmime/kmime_mdn.h>
 
 using namespace MessageCore;
 
