@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ FilterSavedManager::FilterSavedManager(QObject *parent)
 {
 }
 
-FilterSavedManager::~FilterSavedManager()
-{
-}
+FilterSavedManager::~FilterSavedManager() = default;
 
 FilterSavedManager *FilterSavedManager::self()
 {
@@ -109,7 +107,7 @@ void FilterSavedManager::removeFilter(const QString &identifier)
     int numberOfFilter = 0;
     for (Filter *f : std::as_const(lst)) {
         if ((f->identifier() != identifier) && !f->identifier().isEmpty()) {
-            f->save(KSharedConfig::openConfig(), f->filterName(), f->iconName());
+            f->save(KSharedConfig::openConfig(), f->filterName(), f->iconName(), numberOfFilter);
             numberOfFilter++;
         }
     }
@@ -119,7 +117,7 @@ void FilterSavedManager::removeFilter(const QString &identifier)
     lst.clear();
 }
 
-void FilterSavedManager::renameFilter(const QString &identifier, const QString &newName)
+void FilterSavedManager::updateFilter(const QString &identifier, const QString &newName, const QString &iconName)
 {
     KConfigGroup grp(KSharedConfig::openConfig(), "General");
     const int numberFilter = grp.readEntry("NumberFilter").toInt();
@@ -127,6 +125,9 @@ void FilterSavedManager::renameFilter(const QString &identifier, const QString &
         KConfigGroup newGroup(KSharedConfig::openConfig(), QStringLiteral("Filter_%1").arg(i));
         if (newGroup.readEntry("identifier") == identifier) {
             newGroup.writeEntry("name", newName);
+            if (!iconName.isEmpty()) {
+                newGroup.writeEntry("iconName", iconName);
+            }
             newGroup.sync();
             break;
         }
