@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMCHECKSIGNATUREJOB_H
-#define DKIMCHECKSIGNATUREJOB_H
+#pragma once
 
 #include "messageviewer_export.h"
 #include <KMime/Message>
@@ -25,7 +24,13 @@ class MESSAGEVIEWER_EXPORT DKIMCheckSignatureJob : public QObject
 {
     Q_OBJECT
 public:
-    enum class DKIMStatus : int { Unknown = 0, Valid = 1, Invalid = 2, EmailNotSigned = 3, NeedToBeSigned = 4 };
+    enum class DKIMStatus : int {
+        Unknown = 0,
+        Valid = 1,
+        Invalid = 2,
+        EmailNotSigned = 3,
+        NeedToBeSigned = 4,
+    };
     Q_ENUM(DKIMStatus)
 
     enum class DKIMError : int {
@@ -62,7 +67,14 @@ public:
     };
     Q_ENUM(DKIMWarning)
 
-    enum class AuthenticationMethod : int { Unknown = 0, Dkim = 1, Spf = 2, Dmarc = 3, Dkimatps = 4, Auth = 5 };
+    enum class AuthenticationMethod : int {
+        Unknown = 0,
+        Dkim = 1,
+        Spf = 2,
+        Dmarc = 3,
+        Dkimatps = 4,
+        Auth = 5,
+    };
     Q_ENUM(AuthenticationMethod)
 
     struct MESSAGEVIEWER_EXPORT DKIMCheckSignatureAuthenticationResult {
@@ -157,4 +169,3 @@ MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::DKIMCheckS
 MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult &t);
 Q_DECLARE_METATYPE(MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult)
 Q_DECLARE_TYPEINFO(MessageViewer::DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult, Q_MOVABLE_TYPE);
-#endif // DKIMCHECKSIGNATUREJOB_H
