@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -48,7 +48,7 @@ const char *GrantleeHeaderTestStyle::name() const
 QString GrantleeHeaderTestStyle::format(KMime::Message *message) const
 {
     if (!message) {
-        return QString();
+        return {};
     }
     return d->mGrantleeFormatter->toHtml(d->mExtraDisplay, d->mAbsolutePath, d->mMainFilename, this, message, isPrinting());
 }
