@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ public:
     virtual void loadSettings() = 0;
     virtual void saveSettings() = 0;
     virtual void resetSettings() = 0;
-    virtual Q_REQUIRED_RESULT QString helpAnchor() const;
+    Q_REQUIRED_RESULT virtual QString helpAnchor() const;
 Q_SIGNALS:
     void configureChanged();
 };
