@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef REMOTECONTENTDIALOG_H
-#define REMOTECONTENTDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -14,6 +13,10 @@
 namespace MessageViewer
 {
 class RemoteContentWidget;
+/**
+ * @brief The RemoteContentDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_TESTS_EXPORT RemoteContentDialog : public QDialog
 {
     Q_OBJECT
@@ -28,4 +31,3 @@ private:
     RemoteContentWidget *const mRemoveContentWidget;
 };
 }
-#endif // REMOTECONTENTDIALOG_H
