@@ -21,9 +21,7 @@ using namespace MessageViewer;
 class MessageViewer::ConfigureWidgetPrivate
 {
 public:
-    ConfigureWidgetPrivate()
-    {
-    }
+    ConfigureWidgetPrivate() = default;
 
     ~ConfigureWidgetPrivate()
     {
@@ -53,10 +51,7 @@ ConfigureWidget::ConfigureWidget(QWidget *parent)
     connect(d->mSettingsUi->overrideCharacterEncoding, qOverload<int>(&QComboBox::currentIndexChanged), this, &ConfigureWidget::settingsChanged);
 }
 
-ConfigureWidget::~ConfigureWidget()
-{
-    delete d;
-}
+ConfigureWidget::~ConfigureWidget() = default;
 
 void ConfigureWidget::readConfig()
 {
