@@ -6,8 +6,11 @@
 
 #include "opensavedfilefolderwidget.h"
 
+#include <KIO/JobUiDelegate>
 #include <KIO/OpenFileManagerWindowJob>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QTimer>
 
@@ -21,6 +24,7 @@ OpenSavedFileFolderWidget::OpenSavedFileFolderWidget(QWidget *parent)
     : KMessageWidget(parent)
     , mTimer(new QTimer(this))
     , mShowFolderAction(new QAction(i18nc("@action", "Open folder where attachment was saved"), this))
+    , mOpenFileAction(new QAction(i18nc("@action", "Open File"), this))
 {
     mTimer->setSingleShot(true);
     mTimer->setInterval(5s); // 5 seconds
@@ -36,6 +40,8 @@ OpenSavedFileFolderWidget::OpenSavedFileFolderWidget(QWidget *parent)
 
     connect(mShowFolderAction, &QAction::triggered, this, &OpenSavedFileFolderWidget::slotOpenSavedFileFolder);
     addAction(mShowFolderAction);
+    connect(mOpenFileAction, &QAction::triggered, this, &OpenSavedFileFolderWidget::slotOpenFile);
+    addAction(mOpenFileAction);
 }
 
 OpenSavedFileFolderWidget::~OpenSavedFileFolderWidget() = default;
@@ -60,6 +66,21 @@ void OpenSavedFileFolderWidget::setUrls(const QList<QUrl> &urls, FileType fileTy
     }
 }
 
+void OpenSavedFileFolderWidget::slotOpenFile()
+{
+    for (const auto &url : std::as_const(mUrls)) {
+        auto job = new KIO::OpenUrlJob(url);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->setDeleteTemporaryFile(true);
+        connect(job, &KIO::OpenUrlJob::result, this, [this](KJob *job) {
+            if (job->error() == KIO::ERR_USER_CANCELED) {
+                KMessageBox::sorry(this, i18n("KMail was unable to open the attachment."), job->errorString());
+            }
+        });
+        job->start();
+    }
+}
+
 void OpenSavedFileFolderWidget::slotOpenSavedFileFolder()
 {
     if (!mUrls.isEmpty()) {
