@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,7 +15,11 @@
 #include <QPointer>
 #include <QPrinter>
 #include <QTimer>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QWebEngineDownloadItem>
+#else
+#include <QWebEngineDownloadRequest>
+#endif
 #include <QWebEngineProfile>
 
 using namespace WebEngineViewer;
@@ -63,15 +67,28 @@ QPoint WebEnginePage::mapToViewport(const QPoint &pos) const
     return QPoint(pos.x() / zoomFactor(), pos.y() / zoomFactor());
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void WebEnginePage::saveHtml(QWebEngineDownloadItem *download)
+#else
+void WebEnginePage::saveHtml(QWebEngineDownloadRequest *download)
+#endif
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+
     const QString fileName = QFileDialog::getSaveFileName(view(), i18n("Save HTML Page"));
     if (!fileName.isEmpty()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         download->setSavePageFormat(QWebEngineDownloadItem::SingleHtmlSaveFormat);
+#else
+        download->setSavePageFormat(QWebEngineDownloadRequest::SingleHtmlSaveFormat);
+#endif
         download->setDownloadDirectory(QFileInfo(fileName).path());
         download->setDownloadFileName(QFileInfo(fileName).fileName());
         download->accept();
     }
+#else
+#pragma "QT6: NEED TO REIMPLEMENT it"
+#endif
 }
 
 bool WebEnginePage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
@@ -97,8 +114,9 @@ void WebEnginePage::javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMe
 
 bool WebEnginePage::execPrintPreviewPage(QPrinter *printer, int timeout)
 {
-    QPointer<QEventLoop> loop = new QEventLoop;
     bool result = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QPointer<QEventLoop> loop = new QEventLoop;
     QTimer::singleShot(timeout, loop.data(), &QEventLoop::quit);
 
     print(printer, [loop, &result](bool res) {
@@ -110,6 +128,8 @@ bool WebEnginePage::execPrintPreviewPage(QPrinter *printer, int timeout)
 
     loop->exec();
     delete loop;
-
+#else
+#pragma "QT6: NEED TO REIMPLEMENT it"
+#endif
     return result;
 }
